That's because there's a ton of documentation on the W3C standard DOM Model and the W3C standard browser XML standard, and duplicating that in the Pyjamas project would be a great deal of work and would imply that the Pyjamas project is somehow an authority over-and-above the W3C. Use a google search for "W3C DOM XML", "W3C DOM", "W3C DOM Javascript" and other such searches to find so much documentation and help on the subject that you'll be staring at it for days.

Then, start by looking at pyjamas/DOM.py and you will notice that there is a massive prevalance of javascript snippets (way more than any other pyjamas module). It should be plain as day that DOM.py is a way to make the W3C DOM model of web browsers appear to be easily accessible, in python.